@@ -59,6 +59,7 @@ typedef struct
 {
 	gchar *name;
 	gboolean is_func;
+	GdkPixbuf* icon;
 	IAnjutaSymbolType type;
 } CppJavaAssistTag;
 
@@ -107,6 +108,8 @@ static void
 cpp_java_assist_tag_destroy (CppJavaAssistTag *tag)
 {
 	g_free (tag->name);
+	if (tag->icon)
+		g_object_unref (tag->icon);
 	g_free (tag);
 }
 
@@ -158,10 +161,13 @@ create_completion (CppJavaAssist* assist, IAnjutaIterable* iter,
 		if (name != NULL)
 		{
 			CppJavaAssistTag *tag = g_new0 (CppJavaAssistTag, 1);
+			const GdkPixbuf* sym_icon;
 			tag->name = g_strdup (name);
 			DEBUG_PRINT ("Created tag: %s", tag->name);
 			tag->type = ianjuta_symbol_get_sym_type (IANJUTA_SYMBOL (iter),
 													 NULL);
+			sym_icon = ianjuta_symbol_get_icon (IANJUTA_SYMBOL(iter), NULL);
+			tag->icon = sym_icon ? gdk_pixbuf_copy (sym_icon) : NULL;
 			tag->is_func = (tag->type == IANJUTA_SYMBOL_TYPE_PROTOTYPE ||
 			                tag->type == IANJUTA_SYMBOL_TYPE_FUNCTION ||
 							tag->type == IANJUTA_SYMBOL_TYPE_METHOD ||
@@ -368,7 +374,7 @@ cpp_java_assist_update_autocomplete (CppJavaAssist *assist)
 
 	DEBUG_PRINT ("Populating %d proposals", length);
 	
-	if (1) //length <= max_completions)
+	if (length <= max_completions)
 	{
 		GList *node, *suggestions = NULL;
 			
@@ -383,6 +389,7 @@ cpp_java_assist_update_autocomplete (CppJavaAssist *assist)
 				proposal->label = g_strdup(tag->name);
 				
 			proposal->data = tag;
+			proposal->icon = tag->icon;
 			suggestions = g_list_prepend (suggestions, proposal);
 		}
 		suggestions = g_list_reverse (suggestions);
@@ -438,7 +445,10 @@ cpp_java_assist_create_word_completion_cache (CppJavaAssist *assist)
 			ianjuta_symbol_manager_search_file_async (assist->priv->isymbol_manager,
 																				 IANJUTA_SYMBOL_TYPE_UNDEF,
 																				 TRUE,
-																				 IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
+																				 IANJUTA_SYMBOL_FIELD_SIMPLE|
+			                                          							 IANJUTA_SYMBOL_FIELD_TYPE|
+			                                          							 IANJUTA_SYMBOL_FIELD_ACCESS|
+			                                          							 IANJUTA_SYMBOL_FIELD_KIND,
 																				 pattern, file, -1, -1, NULL,
 																				 notify, (IAnjutaSymbolManagerSearchCallback) on_query_data, assist,
 																				 NULL);
@@ -454,7 +464,10 @@ cpp_java_assist_create_word_completion_cache (CppJavaAssist *assist)
 		ianjuta_symbol_manager_search_project_async (assist->priv->isymbol_manager,
 											 types,
 											 TRUE,
-											 IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
+											 IANJUTA_SYMBOL_FIELD_SIMPLE|
+			                                 IANJUTA_SYMBOL_FIELD_TYPE|
+			                                 IANJUTA_SYMBOL_FIELD_ACCESS|
+			                                 IANJUTA_SYMBOL_FIELD_KIND,
 											 pattern, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1, 
 											 NULL,
 											 notify, (IAnjutaSymbolManagerSearchCallback) on_query_data, assist,
@@ -469,7 +482,10 @@ cpp_java_assist_create_word_completion_cache (CppJavaAssist *assist)
 		ianjuta_symbol_manager_search_system_async (assist->priv->isymbol_manager,
 											 types,
 											 TRUE,
-											 IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
+											 IANJUTA_SYMBOL_FIELD_SIMPLE|
+			                                 IANJUTA_SYMBOL_FIELD_TYPE|
+			                                 IANJUTA_SYMBOL_FIELD_ACCESS|
+			                                 IANJUTA_SYMBOL_FIELD_KIND,
 											 pattern, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1,
 											 NULL,
 											 notify, (IAnjutaSymbolManagerSearchCallback) on_query_data, assist,
@@ -594,7 +610,11 @@ cpp_java_assist_show_calltip (CppJavaAssist *assist, gchar *call_context,
 																			 IANJUTA_SYMBOL_TYPE_FUNCTION|
 																			 IANJUTA_SYMBOL_TYPE_METHOD|
 																			 IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
-																			 TRUE, IANJUTA_SYMBOL_FIELD_SIMPLE,
+																			 TRUE, 
+																			 IANJUTA_SYMBOL_FIELD_SIMPLE|
+			                                          						 IANJUTA_SYMBOL_FIELD_TYPE|
+			                                          						 IANJUTA_SYMBOL_FIELD_ACCESS|
+			                                          						 IANJUTA_SYMBOL_FIELD_KIND,
 																			 call_context, file, max_completions, -1, NULL);
 												 
 			if (iter_file) 
@@ -613,7 +633,11 @@ cpp_java_assist_show_calltip (CppJavaAssist *assist, gchar *call_context,
 									   IANJUTA_SYMBOL_TYPE_FUNCTION|
 									   IANJUTA_SYMBOL_TYPE_METHOD|
 									   IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
-									   TRUE, IANJUTA_SYMBOL_FIELD_SIMPLE,
+									   TRUE, 
+									   IANJUTA_SYMBOL_FIELD_SIMPLE|
+			                           IANJUTA_SYMBOL_FIELD_TYPE|
+			                           IANJUTA_SYMBOL_FIELD_ACCESS|
+			                           IANJUTA_SYMBOL_FIELD_KIND,
 									   call_context, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC,
 									   max_completions, -1, NULL);
 	if (iter_project)
@@ -629,7 +653,11 @@ cpp_java_assist_show_calltip (CppJavaAssist *assist, gchar *call_context,
 									   IANJUTA_SYMBOL_TYPE_FUNCTION|
 									   IANJUTA_SYMBOL_TYPE_METHOD|
 									   IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
-									   TRUE, IANJUTA_SYMBOL_FIELD_SIMPLE,
+									   TRUE, 
+									   IANJUTA_SYMBOL_FIELD_SIMPLE|
+			                           IANJUTA_SYMBOL_FIELD_TYPE|
+			                           IANJUTA_SYMBOL_FIELD_ACCESS|
+			                           IANJUTA_SYMBOL_FIELD_KIND,		    
 									   call_context, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC,
 									   max_completions, -1, NULL);
 	if (iter_global)
@@ -711,15 +739,32 @@ on_editor_char_added (IAnjutaEditor *editor, IAnjutaIterable *insert_pos,
 	cpp_java_assist_calltip(assist, enable_calltips, (ch == '\b'));
 }
 
-/* FIXME: find a better tester */
+#define BRACE_LIMIT 100
+
 static gboolean
-is_expression_separator (gchar c)
+is_expression_separator (gchar c, gboolean skip_braces, IAnjutaIterable* iter)
 {
-	if (c == ';' || c == '\n' || c == '\r' || c == '\t' || /*c == '(' || c == ')' || */
-	    c == '{' || c == '}' || c == '=' || c == '<' /*|| c == '>'*/ || c == '\v' || c == '!')
+	IAnjutaEditorAttribute attrib = ianjuta_editor_cell_get_attribute (IANJUTA_EDITOR_CELL(iter),
+	                                                                   NULL);
+	if (attrib == IANJUTA_EDITOR_STRING ||
+	    attrib == IANJUTA_EDITOR_COMMENT)
 	{
+		return FALSE;
+	}
+	
+	if (c == ')' && skip_braces)
+	{
+		cpp_java_util_jump_to_matching_brace (iter, c, BRACE_LIMIT);
 		return TRUE;
 	}
+	else if (c == ')' && !skip_braces)
+		return FALSE;
+	
+	if (c == ';' || c == '\n' || c == '\r' || c == '\t' ||
+	    c == '{' || c == '}' || c == '=' || c == '<' || c == '\v' || c == '!')
+	{
+		return TRUE;
+	}	
 
 	return FALSE;
 }
@@ -727,7 +772,7 @@ is_expression_separator (gchar c)
 static IAnjutaIterable*
 cpp_java_parse_expression (CppJavaAssist* assist, IAnjutaIterable* iter, IAnjutaIterable** start_iter)
 {
-	IAnjutaEditor* editor = editor = IANJUTA_EDITOR (assist->priv->iassist);
+	IAnjutaEditor* editor = IANJUTA_EDITOR (assist->priv->iassist);
 	IAnjutaIterable* res = NULL;
 	IAnjutaIterable* cur_pos = ianjuta_iterable_clone (iter, NULL);
 	gboolean op_start = FALSE;
@@ -741,7 +786,7 @@ cpp_java_parse_expression (CppJavaAssist* assist, IAnjutaIterable* iter, IAnjuta
 
 		DEBUG_PRINT ("ch == '%c'", ch);
 		
-		if (is_expression_separator(ch)) {
+		if (is_expression_separator(ch, FALSE, iter)) {
 			DEBUG_PRINT ("found char '%c' which is an expression_separator", ch);
 			break;
 		}
@@ -776,13 +821,12 @@ cpp_java_parse_expression (CppJavaAssist* assist, IAnjutaIterable* iter, IAnjuta
 			assist->priv->pre_word = ianjuta_editor_get_text (editor,
 			                                                  pre_word_start, pre_word_end, NULL);
 
-			/* Try to get the name of the variable
-			 * FIXME: What about get_widget()-> for example */
+			/* Try to get the name of the variable */
 			while (ianjuta_iterable_previous (cur_pos, NULL))
 			{
 				gchar word_ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL(cur_pos), 0, NULL);
 				
-				if (is_expression_separator(word_ch)) 
+				if (is_expression_separator(word_ch, FALSE, cur_pos)) 
 					break;				
 			}
 			ianjuta_iterable_next (cur_pos, NULL);
@@ -898,7 +942,10 @@ cpp_java_assist_populate (IAnjutaProvider* self, IAnjutaIterable* iter, GError**
 					IAnjutaIterable *children = 
 						ianjuta_symbol_manager_get_members (assist->priv->isymbol_manager,
 						                                    symbol,
-						                                    IANJUTA_SYMBOL_FIELD_SIMPLE,
+						                                    IANJUTA_SYMBOL_FIELD_SIMPLE |
+						                                    IANJUTA_SYMBOL_FIELD_KIND |
+						                                    IANJUTA_SYMBOL_FIELD_ACCESS |
+						                                    IANJUTA_SYMBOL_FIELD_TYPE,
 						                                    NULL);
 					if (children != NULL) {
 						cpp_java_assist_destroy_completion_cache (assist);
