@@ -91,25 +91,6 @@ static GtkTreeStoreClass *parent_class = NULL;
 
 /* Helper functions */
 
-static void
-my_gtk_tree_model_foreach_child (GtkTreeModel *const model,
-                           GtkTreeIter *const parent,
-                           GtkTreeModelForeachFunc func,
-                           gpointer user_data)
-{
-  GtkTreeIter iter;
-  gboolean success = gtk_tree_model_iter_children(model, &iter, parent);
-  while(success)
-  {
-    if(gtk_tree_model_iter_has_child(model, &iter))
-        my_gtk_tree_model_foreach_child (model, &iter, func, NULL);
-
-        success = (!func(model, NULL, &iter, user_data) &&
-               gtk_tree_model_iter_next (model, &iter));
-  }
-}
-
-
 /* Type & interfaces initialization */
 
 static void
@@ -775,148 +756,6 @@ gbf_project_model_find_tree_data (GbfProjectModel 	*model,
 	return retval;
 }
 
-static GbfTreeData *
-recursive_find_group (GtkTreeModel   	*model,
-		   GtkTreeIter     	*parent,
-    		   GtkTreeIter		*found,
-		   GFile		*file)
-{
-	GtkTreeIter iter;
-	gboolean next;
-	GbfTreeData *data = NULL;
-
-	for (next = gtk_tree_model_iter_children (model, &iter, parent);
-	    next;
-	    next = gtk_tree_model_iter_next (model, &iter))
-	{
-		gtk_tree_model_get (model, &iter,
-		    GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
-
-		if (data->type == GBF_TREE_NODE_SHORTCUT)
-		{
-			data = data->shortcut;
-		}
-		if ((data->type == GBF_TREE_NODE_GROUP) && (data->group != NULL) && g_file_equal (data->group, file))
-		{
-			if (found != NULL) *found = iter;
-			return data;
-		}
-
-		data = recursive_find_group (model, &iter, found, file);
-		if (data != NULL) return data;
-	}
-
-	return NULL;
-}
-
-static GbfTreeData *
-recursive_find_target (GtkTreeModel   	*model,
-		   GtkTreeIter     	*parent,
-    		   GtkTreeIter		*found,
-		   const gchar	        *name)
-{
-	GtkTreeIter iter;
-	gboolean next;
-	GbfTreeData *data = NULL;
-
-	for (next = gtk_tree_model_iter_children (model, &iter, parent);
-	    next;
-	    next = gtk_tree_model_iter_next (model, &iter))
-	{
-		gtk_tree_model_get (model, &iter,
-		    GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
-
-		if (data->type == GBF_TREE_NODE_SHORTCUT)
-		{
-			data = data->shortcut;
-		}
-		if ((data->type == GBF_TREE_NODE_TARGET) && (data->name != NULL) && (strcmp (data->name, name) == 0))
-		{
-			if (found != NULL) *found = iter;
-			return data;
-		}
-		else
-		{
-			return NULL;
-		}
-	}
-
-	return NULL;
-}
-
-static GbfTreeData *
-recursive_find_source (GtkTreeModel   	*model,
-		   GtkTreeIter     	*parent,
-		   GtkTreeIter     	*found,
-		   GFile		*file)
-{
-	GtkTreeIter iter;
-	gboolean next;
-	GbfTreeData *data = NULL;
-
-	for (next = gtk_tree_model_iter_children (model, &iter, parent);
-	    next;
-	    next = gtk_tree_model_iter_next (model, &iter))
-	{
-		gtk_tree_model_get (model, &iter,
-		    GBF_PROJECT_MODEL_COLUMN_DATA, &data, -1);
-
-		if (data->type == GBF_TREE_NODE_SHORTCUT)
-		{
-			data = data->shortcut;
-		}
-		if ((data->type == GBF_TREE_NODE_SOURCE) && (data->source != NULL) && g_file_equal (data->source, file))
-		{
-			if (found != NULL) *found = iter;
-			return data;
-		}
-		
-		data = recursive_find_group (model, &iter, found, file);
-		if (data != NULL) return data;
-	}
-
-	return NULL;
-}
-
-static GbfTreeData*
-gbf_project_model_find_uri (GbfProjectModel     *model,
-    			    const gchar         *uri,
-    			    GbfTreeNodeType     type)
-{
-	GFile *file;
-	GFile *group;
-	gchar *name;
-	GbfTreeData *data = NULL;
-	GtkTreeIter iter;
-
-	file = g_file_new_for_uri (uri);
-	switch (type)
-	{
-	case GBF_TREE_NODE_SOURCE:
-		data = recursive_find_source (GTK_TREE_MODEL (model), NULL, NULL, file);
-		break;
-	case GBF_TREE_NODE_GROUP:
-		data = recursive_find_group (GTK_TREE_MODEL (model), NULL, NULL, file);
-		break;
-	case GBF_TREE_NODE_TARGET:
-		group = g_file_get_parent (file);
-		name = g_file_get_basename (file);
-		if (recursive_find_group (GTK_TREE_MODEL (model), NULL, &iter, group))
-		{
-			data = recursive_find_target (GTK_TREE_MODEL (model), &iter, NULL, name);
-		}
-		g_free (name);
-		g_object_unref (group);
-		break;
-	default:
-		break;
-	}
-		
-	g_object_unref (file);
-
-	return data;
-}
-
 GbfProjectModel *
 gbf_project_model_new (IAnjutaProject *project)
 {
