@@ -81,7 +81,6 @@ static void
 sourceview_io_class_init (SourceviewIOClass *klass)
 {
 	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	GObjectClass* parent_class = G_OBJECT_CLASS (klass);
 
 	object_class->finalize = sourceview_io_finalize;
 
@@ -290,7 +289,7 @@ sourceview_io_save_as (SourceviewIO* sio, GFile* file)
 	
 	cancel_monitor (sio);
 	
-	backup = anjuta_preferences_get_int_with_default (sio->sv->priv->prefs,
+	backup = anjuta_preferences_get_bool_with_default (sio->sv->priv->prefs,
 													  "sourceview.backup", TRUE);
 	
 	if (sio->last_encoding == NULL)
